"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
exports.getConstructor = getConstructor;
var _getSuperCtor = _interopRequireDefault(require("./getSuperCtor.js"));
var _isEmptyFunction = require("./isEmptyFunction.js");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
// get latest non-empty constructor function through inherits chain

/**
 * Returns the first(latest) non-empty constructor in the inheritance chain of the given constructor that has own properties.
 *
 * @param {function} ctor - The constructor to get the first non-empty constructor of.
 * @returns {function} The first(latest) non-empty constructor in the inheritance chain of the given constructor.
 */
function getConstructor(ctor) {
  let result = ctor;
  let isEmpty = (0, _isEmptyFunction.isEmptyFunction)(result);
  let v = (0, _getSuperCtor.default)(result);
  while (isEmpty && v && v !== Object) {
    result = v;
    v = (0, _getSuperCtor.default)(result);
    isEmpty = (0, _isEmptyFunction.isEmptyFunction)(result);
  }
  return result;
}
var _default = exports.default = getConstructor;