"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
exports.getParentClass = getParentClass;
var _getOwnPropValue = _interopRequireDefault(require("./getOwnPropValue.js"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const getPrototypeOf = Object.getPrototypeOf;

/**
 * Returns the parent class constructor of a given constructor(class) or object.
 *
 * @param {Function|object} ctor The constructor function or object to get the parent class from.
 * @returns {Function|undefined|null} The parent class constructor or undefined/null if there is no parent class.
 */
function getParentClass(ctor) {
  let result;
  if (typeof ctor === 'object' && ctor !== null) {
    ctor = getPrototypeOf(ctor);
    ctor = (0, _getOwnPropValue.default)(ctor, 'Class') || ctor.constructor;
  }
  if (typeof ctor === 'function') {
    result = (0, _getOwnPropValue.default)(ctor, 'super_');
    if (!result) {
      result = getPrototypeOf(ctor.prototype);
      if (result) {
        result = (0, _getOwnPropValue.default)(result, 'Class') || result.constructor;
        if (result === Function || result === Object) {
          result = null;
        }
      }
    }
  }
  return result;
}
var _default = exports.default = getParentClass;