"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
exports.isInheritedFrom = isInheritedFrom;
var _isInheritedFromStr = require("./isInheritedFromStr.js");
var _getSuperCtor = _interopRequireDefault(require("./getSuperCtor.js"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const getPrototypeOf = Object.getPrototypeOf;
const objectSuperCtor = getPrototypeOf(Object);

/**
 *   Determines if a constructor(class) is inherited from a given super constructor(class).
 *   @param {Function} ctor - The constructor function to check.
 *   @param {Function|string} superCtor - The super constructor to check for inheritance. Can be the name of the super constructor.
 *   @param {boolean} [throwError=false] - If true, an error will be thrown if a circular inheritance is found. defaults to false.
 *   @returns {boolean|Function} - If the constructor is inherited from the super constructor, returns the constructor.
 *   Otherwise, returns false.
 */
function isInheritedFrom(ctor, superCtor, throwError) {
  if (typeof superCtor === 'string') {
    return (0, _isInheritedFromStr.isInheritedFromStr)(ctor, superCtor, throwError);
  }
  if (ctor === superCtor) {
    if (throwError) throw new Error('Circular inherits found!');else return true;
  }
  let ctorSuper = (0, _getSuperCtor.default)(ctor);
  let result = ctorSuper === superCtor;
  const checked = [];
  checked.push(ctor);
  while (!result && (ctor = ctorSuper) != null && ctorSuper !== objectSuperCtor) {
    ctorSuper = (0, _getSuperCtor.default)(ctor);
    if (checked.includes(ctor)) {
      if (throwError) throw new Error('Circular inherits found!');else return true;
    }
    checked.push(ctor);
    result = ctorSuper === superCtor;
  }
  if (result) {
    result = ctor;
    ctor = checked[0];
    if (ctor.mixinCtor_ === result) {
      result = ctor;
    }
  }
  return result;
}
var _default = exports.default = isInheritedFrom;