"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
exports.newPrototype = newPrototype;
var _getConstructor = require("./getConstructor.js");
var _isEmptyFunction = require("./isEmptyFunction.js");
var _clone2 = require("./_clone.js");
/**
 *  Creates a new object with a prototype chain from a given class and constructor function.
 *  @param {Function} aClass - The class to use as prototype chain.
 *  @param {Function} [aConstructor] - The constructor function for the new object.
 *  @returns {Object} - The newly created prototype object.
 */
function newPrototype(aClass, aConstructor) {
  // Object.create(prototype) only for ES5
  // Object.create(prototype, initProps) only for ES6
  // For Browser not support ES5/6:
  //  var Object = function() { this.constructor = aConstructor; };
  //  Object.prototype = aClass.prototype;
  //  return new Object();
  const ctor = (0, _isEmptyFunction.isEmptyFunction)(aConstructor) ? (0, _getConstructor.getConstructor)(aClass) : aConstructor;
  let result;
  if (Object.create) {
    // typeof Object.create === 'function'
    result = Object.create(aClass.prototype, {
      Class: {
        value: aConstructor,
        enumerable: false,
        writable: true,
        configurable: true
      },
      constructor: {
        value: ctor,
        enumerable: false,
        writable: true,
        configurable: true
      }
    });
  } else {
    const Obj = function obj() {
      this.constructor = ctor;
      this.Class = aConstructor;
    };
    Obj.prototype = aClass.prototype;
    result = new Obj();
  }
  (0, _clone2._clone)(result, aConstructor.prototype, function (k, v) {
    if (['Class', 'constructor'].includes(k)) {
      return;
    }
    return v;
  });
  return result;
}
;
var _default = exports.default = newPrototype;